@@ -70,6 +70,7 @@ if TYPE_CHECKING:
     from .state import ConnectionState
     from .types.components import Component as ComponentPayload
     from .types.embed import Embed as EmbedPayload
+    from .types.interactions import MessageInteraction as MessageInteractionPayload
     from .types.member import Member as MemberPayload, UserWithMember as UserWithMemberPayload
     from .types.message import (
         Attachment as AttachmentPayload,
@@ -93,6 +94,7 @@ __all__ = (
     "PartialMessage",
     "MessageReference",
     "DeletedReferencedMessage",
+    "MessageInteraction",
 )
 
 
@@ -543,6 +545,75 @@ def flatten_handlers(cls):
     return cls
 
 
+class MessageInteraction(Hashable):
+    """Represents a message's interaction data.
+
+    A message's interaction data is a property of a message when the message
+    is a response to an interaction from any bot.
+
+    .. versionadded:: 2.1
+
+    .. container:: operations
+
+        .. describe:: x == y
+
+            Checks if two message interactions are equal.
+
+        .. describe:: x != y
+
+            Checks if two interaction messages are not equal.
+
+        .. describe:: hash(x)
+
+            Returns the message interaction's hash.
+
+    Attributes
+    -----------
+    data: Dict[:class:`str`, Any]
+        The raw data from the interaction.
+    id: :class:`int`
+        The interaction's ID.
+    type: :class:`InteractionType`
+        The interaction type.
+    name: :class:`str`
+        The name of the application command.
+    user: Union[:class:`User`, :class:`Member`]
+        The :class:`User` who invoked the interaction or :class:`Member` if the interaction
+        occurred in a guild.
+    """
+
+    __slots__ = (
+        "_state",
+        "data",
+        "id",
+        "type",
+        "name",
+        "user",
+    )
+
+    def __init__(
+        self, *, data: MessageInteractionPayload, guild: Optional[Guild], state: ConnectionState
+    ):
+        self._state: ConnectionState = state
+
+        self.data: MessageInteractionPayload = data
+        self.id: int = int(data["id"])
+        self.type: int = data["type"]
+        self.name: str = data["name"]
+        if "member" in data and guild is not None:
+            self.user = Member(state=self._state, guild=guild, data={**data["member"], "user": data["user"]})  # type: ignore
+        else:
+            self.user = self._state.create_user(data=data["user"])
+
+    def __repr__(self):
+        return f"<{self.__class__.__name__} id={self.id} type={self.type} name={self.name} user={self.user!r}>"
+
+    @property
+    def created_at(self) -> datetime.datetime:
+        """:class:`datetime.datetime`: The interaction's creation time in UTC."""
+        return utils.snowflake_time(self.id)
+
+
 @flatten_handlers
 class Message(Hashable):
     r"""Represents a message from Discord.
@@ -658,6 +729,8 @@ class Message(Hashable):
         .. versionadded:: 2.0
     guild: Optional[:class:`Guild`]
         The guild that the message belongs to, if applicable.
+    interaction: Optional[:class:`MessageInteraction`]
+        The interaction data of a message, if applicable.
     """
 
     __slots__ = (
@@ -676,6 +749,7 @@ class Message(Hashable):
         "mention_everyone",
         "embeds",
         "id",
+        "interaction",
         "mentions",
         "author",
         "attachments",
@@ -781,6 +855,12 @@ class Message(Hashable):
             except KeyError:
                 continue
 
+        self.interaction: Optional[MessageInteraction] = (
+            MessageInteraction(data=data["interaction"], guild=self.guild, state=self._state)
+            if "interaction" in data
+            else None
+        )
+
     def __repr__(self) -> str:
         name = self.__class__.__name__
         return f"<{name} id={self.id} channel={self.channel!r} type={self.type!r} author={self.author!r} flags={self.flags!r}>"
